@@ -1,4 +1,4 @@
-# $Id: IDspaceSet.pm 2011-06-06 erick.antezana $
+# $Id: IDspaceSet.pm 2014-06-06 erick.antezana $
 #
 # Module  : IDspaceSet.pm
 # Purpose : A set of IDspaces.
@@ -62,7 +62,7 @@ sub equals {
 			foreach (@this, @that) {
 				$count{$_}++;
 			}
-			foreach my $count (values %count) {
+			foreach my $count (sort values %count) {
 				if ($count != 2) {
 					$result = 0;
 					last;
